﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

/**
 * \file AudioManager.cs
 * \brief Permet de gerer le son d'un element en particulier
 * 
 * \version 1.0
 * \author Thibault CLAUSS
 */
public class AudioManager : MonoBehaviour
{
    /** Playlist des musiques du jeu. \n
      * Doit être relié à la plylist dans */
    public AudioClip[] playlist;

    /** Source audio qui permet de gerer le son de cette source specifiquement. \n
      * Doit être relié à une source audio dans Unity.*/
    public AudioSource audioSource;

    /** Index des musiques qui permet de classer et d'ordonner les musiques.*/ 
    private int musicIndex = 0;

    /**
     * Méthode propre à Unity qui s'execute au lancement de l'objet utilisant ce script. \n
     * Ici elle est utilisé pour lancer la musique.
     */
    void Awake()
    {
        // Recupere et lance la premiere musique de la playlist.
        audioSource.clip = playlist[0];
        audioSource.Play();
    }

    /**
     * Méthode propre à Unity qui execute une action à chaque mise à jour visuel du jeu. \n
     * Ici elle est utilisé pour vérifier si la musique est terminé et si oui elle en lance une autre.
     */
    void Update()
    {
        // Si la musique est fini, la fonction passe à la musique suivante.
        if (!audioSource.isPlaying)
        {
            PlayNextSong();
        }
    }

    /** Méthode permettant de lancer la prochaine musique.*/
    void PlayNextSong()
    {
        // Recupere la prochaine musique et reviens à la première musique si on arrive au bout de la playlist.
        musicIndex = (musicIndex++) % playlist.Length;
        
        // Lance la musique selectionné.
        audioSource.clip = playlist[musicIndex];
        audioSource.Play();
    }
}
