﻿using UnityEngine;
using UnityEngine.SceneManagement;
using System.Collections;

/**
 * \file LoadSpecificScene.cs
 * \brief Permet de charger la scène/niveau voulu.
 * 
 * \version 1.0
 * \author Julien SCHUBNEL
 */
public class LoadSpecificScene : MonoBehaviour
{
    /** Le nom de la scène à charger. \n
     Doit être spécifié dans Unity.*/
    public string NomSceneToLoad;
    /** L'animation de fondu au noir*/
    public Animator fadeSystem;

    /**
     * \fn private void OnTriggerEnter2D(Collider2D collision)
     * \brief Fonction propre à Unity qui se lance lorsqu'un objet rentre en contact avec la HitBox de l'objet qui utilise se script. \n
     * Ici on l'utilise lorsqu'un joueur entre en contact avec la zone de fin de niveau pour lancer le prochain niveau.
     * 
     * \param collision : Collider2D représentant l'objet du joueur.
     */
    public void OnTriggerEnter2D(Collider2D collision)
    {

        if (collision.CompareTag("Player"))
        {
            StartCoroutine(LoadNextScene());
        }
    }

    /**
     * Coroutine utilisé par Unity pour bloquer toute autre processus. \n
     * Ici on l'utilise pour lancer l'animation de fondu au noir, attendre une seconde (donc l'écran sera noir) puis charger le nouveau niveau.
     */
    public IEnumerator LoadNextScene()
    {
        fadeSystem.SetTrigger("FadeIn");
        yield return new WaitForSeconds(1f);
        SceneManager.LoadScene(NomSceneToLoad);
    }
}
