﻿/**
 * \file PauseMenu.cs
 * \brief Permet de manipuler le menu pause.
 * 
 * \version 1.0
 * \author Julien SCHUBNEL
 */

using UnityEngine;
using UnityEngine.SceneManagement;

public class PauseMenu : MonoBehaviour
{
    /** Permet de savoir si le jeu est en pause \n
     Est par défaut égal à false.*/
    public static bool JeuEnPause = false;

    /** Objet représentant le menu pause. \n
     Doit être relié au menu pause dans Unity.*/
    public GameObject pauseMenuUI;

    /**
     * Méthode propre à Unity qui execute une action à chaque mise à jour visuel du jeu. \n
     * Ici elle est utilisé pour que lorsque le joueur appuie sur la touche "Echap", le menu pause s'ouvre ou se ferme.
     */
    void Update()
    {
        // On regarde si la touche echap est utilisé
        if (Input.GetKeyDown(KeyCode.Escape))
        {
            // Si le jeu est en pause on le fait reprendre sinon on le met en pause
            if(JeuEnPause == true)
            {
                Reprendre();
            }
            else
            {
                Pause();
            }
        }
    }

    /**
     * Méthode permettant d'activer le menu pause et d'arreter le temps (donc le joueur ne peut plus jouer).
     */
    void Pause()
    {
        // Activer menu pause
        pauseMenuUI.SetActive(true);
        // Arrêter le temps 
        Time.timeScale = 0;
        // Changer le statut du jeu
        JeuEnPause = true;
    }

    /**
     * Méthode permettant de quitter le menu pause et de relancer le temps (donc le joueur peut jouer). \n
     * Doit être relié à un bouton dans le menu pause.
     */
    public void Reprendre()
    {
        // Désactiver le menu pause
        pauseMenuUI.SetActive(false);
        // Relancer le temps 
        Time.timeScale = 1;
        // Changer le statut du jeu
        JeuEnPause = false;
    }

    /**
 * Méthode permettant de recommencer le niveau \n
 * Doit être relié à un bouton dans le menu pause.
 */
    public void Recommencer()
    {
        // Pour que le jeu ne reste pas en pause quand on le reprend
        Reprendre();
        // On recharge la scène
        SceneManager.LoadScene(SceneManager.GetActiveScene().buildIndex);
    }

    /**
     * Méthode permettant de quitter le niveau et d'aller au menu principal \n
     * Doit être relié à un bouton dans le menu pause.
     */
    public void LoadMainMenu()
    {
        // Pour que le jeu ne reste pas en pause quand on le reprend
        Reprendre();
        // Charge la scène menu
        SceneManager.LoadScene("MainMenu");
    }
}
